@@ -19,16 +19,16 @@ class Translation(object):
 
     def __init__(
         self,
-        pt_BR: str = None,
-        cn_CN: str = None,
-        de_DE: str = None,
-        es_ES: str = None,
-        fr_FR: str = None,
-        it_IT: str = None,
-        ko_KR: str = None,
-        ru_RU: str = None,
-        en_US: str = None,
-        translations: dict = None,
+        pt_BR: typing.Optional[str] = None,
+        cn_CN: typing.Optional[str] = None,
+        de_DE: typing.Optional[str] = None,
+        es_ES: typing.Optional[str] = None,
+        fr_FR: typing.Optional[str] = None,
+        it_IT: typing.Optional[str] = None,
+        ko_KR: typing.Optional[str] = None,
+        ru_RU: typing.Optional[str] = None,
+        en_US: typing.Optional[str] = None,
+        translations: typing.Optional[dict] = None,
         *args,
         **kwargs,
     ):
